﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using PdfDocument;

namespace CalcHelper
{
    public partial class GoToBoxedPage : Form
    {
        public uint selBoxedPage { get; set; }

        private string boxTypeText;

        public GoToBoxedPage(Pdf.pageNavMode pageMode, ref List<uint> boxedPages)
        {
            InitializeComponent();

            switch (pageMode)
            {
                case (Pdf.pageNavMode.boxedpages):

                    boxTypeText = "Boxed";
                    break;

                case (Pdf.pageNavMode.checkbox):

                    boxTypeText = "Checkbox";
                    break;

                case (Pdf.pageNavMode.code39):

                    boxTypeText = "Code39 Barcode";
                    break;

                case (Pdf.pageNavMode.int2of5):

                    boxTypeText = "Int2of5 Barcode";
                    break;

                case (Pdf.pageNavMode.pdf417):

                    boxTypeText = "Pdf417 Barcode";
                    break;

                case (Pdf.pageNavMode.qrcode):

                    boxTypeText = "QR Code";
                    break;
            }

            this.Text = string.Format("Go To {0} Page", boxTypeText);

            CancelButton = canGoBoxedPageBtn;
            AcceptButton = okGoBoxedPageBtn;

            boxedPagesCombo.DataSource = boxedPages;

            if (boxedPages.Count > 0)
            {
                boxedPagesCombo.SelectedIndex = 0;
            }
        }

        private void boxedPagesCombo_KeyPress(object sender, KeyPressEventArgs e)
        {
            // Allow backspace key.
            if (e.KeyChar != '\b')
            {
                /*
                 * Allow just digits 0-9.
                 * "Set Handled to true to cancel the KeyPress event",
                 * so a 'bad' char sets e.handled to true which 'ignores'
                 * the char and we inform user.
                */
                e.Handled = !char.IsDigit(e.KeyChar);

                if (e.Handled)
                {
                    CustomToolTip toolTip = new CustomToolTip(boxedPagesCombo, "  Unacceptable Character", "E");
                    toolTip.ShowToolTip(string.Format("{0}You can only type a number here.{0} ", Environment.NewLine));
                }
            }
        }

        private void okGoBoxedPageBtn_Click(object sender, EventArgs e)
        {
            uint page = 0;

            uint.TryParse(boxedPagesCombo.Text, out page);

            if (boxedPagesCombo.Items.Contains(page))
            {
                this.selBoxedPage = page;
                this.DialogResult = DialogResult.OK;
                this.Close();
            }
            else
            {
                CustomToolTip toolTip = new CustomToolTip(boxedPagesCombo, string.Format("  Not A {0} Page", boxTypeText), "W");
                toolTip.ShowToolTip(string.Format("{1}The page you selected is not a {0} page.{1} ", boxTypeText.ToLower(), Environment.NewLine));
            }
        }

        private void canGoBoxedPageBtn_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.Cancel;
            this.Close();
        }
    }
}
